( cd usr/lib ; rm -rf libmp4.so.0 )
( cd usr/lib ; ln -sf libmp4.so.0.0.0 libmp4.so.0 )
( cd usr/lib ; rm -rf libmp4.so )
( cd usr/lib ; ln -sf libmp4.so.0.0.0 libmp4.so )
( cd usr/lib ; rm -rf libmp4v2.so.0 )
( cd usr/lib ; ln -sf libmp4v2.so.0.0.0 libmp4v2.so.0 )
( cd usr/lib ; rm -rf libmp4v2.so )
( cd usr/lib ; ln -sf libmp4v2.so.0.0.0 libmp4v2.so )
( cd usr/lib ; rm -rf libmp4av.so.0 )
( cd usr/lib ; ln -sf libmp4av.so.0.0.0 libmp4av.so.0 )
( cd usr/lib ; rm -rf libmp4av.so )
( cd usr/lib ; ln -sf libmp4av.so.0.0.0 libmp4av.so )
( cd usr/lib ; rm -rf libmsg_queue.so.0 )
( cd usr/lib ; ln -sf libmsg_queue.so.0.0.0 libmsg_queue.so.0 )
( cd usr/lib ; rm -rf libmsg_queue.so )
( cd usr/lib ; ln -sf libmsg_queue.so.0.0.0 libmsg_queue.so )
( cd usr/lib ; rm -rf libsdp.so.0 )
( cd usr/lib ; ln -sf libsdp.so.0.0.0 libsdp.so.0 )
( cd usr/lib ; rm -rf libsdp.so )
( cd usr/lib ; ln -sf libsdp.so.0.0.0 libsdp.so )
( cd usr/lib ; rm -rf libmpeg4ipSDL-1.2.so.0 )
( cd usr/lib ; ln -sf libmpeg4ipSDL-1.2.so.0.7.0 libmpeg4ipSDL-1.2.so.0 )
( cd usr/lib ; rm -rf libmpeg4ipSDL.so )
( cd usr/lib ; ln -sf libmpeg4ipSDL-1.2.so.0.7.0 libmpeg4ipSDL.so )
( cd usr/lib ; rm -rf libhttp.so.0 )
( cd usr/lib ; ln -sf libhttp.so.0.0.0 libhttp.so.0 )
( cd usr/lib ; rm -rf libhttp.so )
( cd usr/lib ; ln -sf libhttp.so.0.0.0 libhttp.so )
( cd usr/lib ; rm -rf libmp4util.so.0 )
( cd usr/lib ; ln -sf libmp4util.so.0.0.0 libmp4util.so.0 )
( cd usr/lib ; rm -rf libmp4util.so )
( cd usr/lib ; ln -sf libmp4util.so.0.0.0 libmp4util.so )
( cd usr/lib ; rm -rf libh264util.so.0 )
( cd usr/lib ; ln -sf libh264util.so.0.0.0 libh264util.so.0 )
( cd usr/lib ; rm -rf libh264util.so )
( cd usr/lib ; ln -sf libh264util.so.0.0.0 libh264util.so )
( cd usr/lib/mp4player_plugin ; rm -rf raw_audio_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf raw_audio_plugin.so.0.0.0 raw_audio_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf raw_audio_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf raw_audio_plugin.so.0.0.0 raw_audio_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf celp_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf celp_plugin.so.0.0.0 celp_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf celp_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf celp_plugin.so.0.0.0 celp_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf a52_audio_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf a52_audio_plugin.so.0.0.0 a52_audio_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf a52_audio_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf a52_audio_plugin.so.0.0.0 a52_audio_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf ffmpeg_audio_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf ffmpeg_audio_plugin.so.0.0.0 ffmpeg_audio_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf ffmpeg_audio_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf ffmpeg_audio_plugin.so.0.0.0 ffmpeg_audio_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf raw_video_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf raw_video_plugin.so.0.0.0 raw_video_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf raw_video_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf raw_video_plugin.so.0.0.0 raw_video_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf h261_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf h261_plugin.so.0.0.0 h261_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf h261_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf h261_plugin.so.0.0.0 h261_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf mpeg2dec_video_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf mpeg2dec_video_plugin.so.0.0.0 mpeg2dec_video_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf mpeg2dec_video_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf mpeg2dec_video_plugin.so.0.0.0 mpeg2dec_video_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf ffmpeg_video_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf ffmpeg_video_plugin.so.0.0.0 ffmpeg_video_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf ffmpeg_video_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf ffmpeg_video_plugin.so.0.0.0 ffmpeg_video_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf isma_rtp_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf isma_rtp_plugin.so.0.0.0 isma_rtp_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf isma_rtp_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf isma_rtp_plugin.so.0.0.0 isma_rtp_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf isma_enc_rtp_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf isma_enc_rtp_plugin.so.0.0.0 isma_enc_rtp_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf isma_enc_rtp_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf isma_enc_rtp_plugin.so.0.0.0 isma_enc_rtp_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf h261_rtp_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf h261_rtp_plugin.so.0.0.0 h261_rtp_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf h261_rtp_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf h261_rtp_plugin.so.0.0.0 h261_rtp_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf isma_enc_video_rtp_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf isma_enc_video_rtp_plugin.so.0.0.0 isma_enc_video_rtp_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf isma_enc_video_rtp_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf isma_enc_video_rtp_plugin.so.0.0.0 isma_enc_video_rtp_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf h264_rtp_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf h264_rtp_plugin.so.0.0.0 h264_rtp_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf h264_rtp_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf h264_rtp_plugin.so.0.0.0 h264_rtp_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf rfc2429_rtp_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf rfc2429_rtp_plugin.so.0.0.0 rfc2429_rtp_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf rfc2429_rtp_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf rfc2429_rtp_plugin.so.0.0.0 rfc2429_rtp_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf rfc3267_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf rfc3267_plugin.so.0.0.0 rfc3267_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf rfc3267_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf rfc3267_plugin.so.0.0.0 rfc3267_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf aac_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf aac_plugin.so.0.0.0 aac_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf aac_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf aac_plugin.so.0.0.0 aac_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf mp3_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf mp3_plugin.so.0.0.0 mp3_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf mp3_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf mp3_plugin.so.0.0.0 mp3_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf mpeg4_iso_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf mpeg4_iso_plugin.so.0.0.0 mpeg4_iso_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf mpeg4_iso_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf mpeg4_iso_plugin.so.0.0.0 mpeg4_iso_plugin.so )
( cd usr/lib/mp4player_plugin ; rm -rf wav_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; ln -sf wav_plugin.so.0.0.0 wav_plugin.so.0 )
( cd usr/lib/mp4player_plugin ; rm -rf wav_plugin.so )
( cd usr/lib/mp4player_plugin ; ln -sf wav_plugin.so.0.0.0 wav_plugin.so )
